# Enhancement Proposals

Enhancement Proposals are a formal way of proposing large feature additions to the **Django Ninja Framework**

You can create a proposal by making a pull request with a new page under [`docs/proposals`](https://github.com/vitalik/django-ninja/tree/master/docs/docs/proposals) or by creating an [issue on github](https://github.com/vitalik/django-ninja/issues)

Please check current proposals:

 - [Class Based Operations](cbv)
 - [Response Schema](responses)
 - [Schemas from Django models](models)
